@@ -36,4 +36,12 @@ def init_mft():
 
 @app.command("stop")
 def init_mft():
-  bootstrap.stop_mft()
\ No newline at end of file
+  bootstrap.stop_mft()
+
+@app.command("update")
+def init_mft():
+  bootstrap.update_mft()
+
+@app.command("log")
+def init_mft():
+  bootstrap.print_log()
\ No newline at end of file
